'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.containsRemoteObject = containsRemoteObject;

var _isObject = require('lodash/isObject');

var _isObject2 = _interopRequireDefault(_isObject);

var _isFunction = require('lodash/isFunction');

var _isFunction2 = _interopRequireDefault(_isFunction);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Determines if an object is, or contains, an Electron remote object.
 * Under the surface, getting or setting properties on remote objects triggers
 * synchronous IPC messages. So we want to avoid storing them at all costs.
 *
 * Refer to https://github.com/electron/electron/blob/master/docs/api/remote.md#remote-objects.
 *
 * @param  {Object} obj An object to test
 * @return {Boolean}    True if it is a remote object, false otherwise
 */
function containsRemoteObject(obj) {
  if (!process || !process.atomBinding) return false;
  if (!(0, _isObject2.default)(obj) && !(0, _isFunction2.default)(obj)) return false;

  var v8util = process.atomBinding('v8_util');
  if (v8util.getHiddenValue(obj, 'atomId')) return true;

  return Object.keys(obj).find(function (x) {
    return containsRemoteObject(obj[x]);
  });
}